Internal workhorse function to calculate the calibration constant value that attains level alpha for given method for time-to-event data
findconst.surv(n, p0, alpha, type, tau, maxInf = "expected", param = NULL)The calibration constant used for subsequent stopping boundary calculation
Maximum sample size for safety monitoring
The probability of a toxicity occurring in tau units of time under the null hypothesis
The nominal type I error/false positive rate for the stopping rule, under an assumption that the cumulative number of events follows a Poisson process over the study duration.
The method used for constructing the stopping rule
Length of observation period
Specification of the maximum information (maximum exposure time) used for designing the stopping rule. Options include the expected exposure time for n patients used H0 ("expected") and the maximum possible exposure time ("maximum"). Default is "expected" (expected exposure time in cohort).
A vector of the extra parameter(s) needed for certain stopping rule methods. For Wang-Tsiatis tests, this is the Delta parameter. For truncated SPRT, this is the targeted alternative toxicity probability p1. For Bayesian Gamma-Poisson model, this is the vector of hyperparameters (shape,rate) for the gamma prior on the toxicity event rate.