Learn R Programming

stoppingrule (version 0.6)

lines.rule.tite: Add Stopping Rule Curve to Current Plot (TITE Method)

Description

Add a TITE stopping rule graphically as a curve on current plot

Usage

# S3 method for rule.tite
lines(x, ...)

Value

No return value; function solely modifies current plot

Arguments

x

A rule.tite object calculated by calc.rule.tite() function

...

Other options to be passed to generic lines function

Examples

Run this code
if (FALSE) # Binomial Pocock test in 50 patient cohort at 10% level, expected toxicity probability of 20%
poc_rule = calc.rule.tite(n=50,p0=0.20,alpha=0.10,type="Pocock")

# Bayesian beta-extended binomial method in 50 patient cohort at 10% level,
# expected toxicity probability of 20%
bb_rule = calc.rule.tite(n=50,p0=0.20,alpha=0.10,type="BB",param=c(2,8))

# Plot stopping boundaries for stopping rules
plot(poc_rule,col="blue")
lines(bb_rule,col="red")

Run the code above in your browser using DataLab