Internal workhorse function to calculate operating characteristics for a given stopping rule and toxicity probability
opchars.bin(rule, p, tau = NULL, A = NULL)A list containing the toxicity probability p, and the corresponding rejection probability and expected number of events. If tau and A are also specified, the expected number of enrolled patients and the expected calendar time at the point of stopping/study end are also included.
A rule.bin object calculated by calc.rule.bin() function
The toxicity probability
Length of observation period
Length of the enrollment period.