Internal workhorse function to calculate operating characteristics for a given stopping rule and toxicity probability
opchars.surv(rule, p, MC, A, s = 1)A list containing the rejection probability p, and the corresponding
rejection probability and number of events. If MC is not NULL, the expected
number of enrolled patients and total follow up time are also included.
A rule.surv object calculated by calc.rule.surv() function
The toxicity probability
Number of Monte Carlo replicates to simulate for estimating operating characteristics. If MC = 0, a Poisson process assumption on the event process is used to compute operating characteristics.
Length of the enrollment period. Only required if MC > 0.
Shape parameter for the Weibull distribution used to simulate event times. Only required if MC > 0.