Internal workhorse function to calculate operating characteristics for a given stopping rule and toxicity probability
opchars.tite(rule, p, tau, MC, A, family, s)A list containing the toxicity probability p, and the corresponding rejection probability and expected number of events. If tau and A are also specified, the expected number of enrolled patients and the expected calendar time at the point of stopping/study end are also included.
A rule.tite object with the safety stopping rule for evaluation
Vector of cumulative incidence probabilities at time tau for all causes (length 1 for survival, 2 for competing risks)
Length of observation period
Number of Monte Carlo replicated datasets to simulate
Length of accrual period
Event time distribution, choices including Weibull distribution ('weibull') and power family ('power')
Shape parameter for Weibull distribution or power parameter for power family