Learn R Programming

stoppingrule (version 0.6)

stopping.prob.surv: Calculating the stopping probability given a rejection boundary (Survival Data)

Description

Internal workhouse function to calculate the stopping probability given a rejection boundary for time-to-event data

Usage

stopping.prob.surv(bnd, p)

Value

A list of three: stopping probabilities at each stage, total stopping probability, and non-stopping probabilities of each possible number of events at the last stage.

Arguments

bnd

A list object calculated by calc.bnd.surv function

p

True toxicity probability