Internal workhouse function to calculate the stopping probability given a rejection boundary for time-to-event data
stopping.prob.surv(bnd, p)A list of three: stopping probabilities at each stage, total stopping probability, and non-stopping probabilities of each possible number of events at the last stage.
A list object calculated by calc.bnd.surv function
True toxicity probability